Class: Google::Apis::ServicedirectoryV1beta1::ServiceDirectoryService
- Inherits:
-
Core::BaseService
- Object
- Core::BaseService
- Google::Apis::ServicedirectoryV1beta1::ServiceDirectoryService
- Defined in:
- lib/google/apis/servicedirectory_v1beta1/service.rb
Overview
Service Directory API
Service Directory is a platform for discovering, publishing, and connecting services.
Constant Summary collapse
- DEFAULT_ENDPOINT_TEMPLATE =
"https://servicedirectory.$UNIVERSE_DOMAIN$/"
Instance Attribute Summary collapse
-
#key ⇒ String
API key.
-
#quota_user ⇒ String
Available to use for quota purposes for server-side applications.
Instance Method Summary collapse
-
#create_project_location_namespace(parent, namespace_object = nil, namespace_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ServicedirectoryV1beta1::Namespace
Creates a namespace, and returns the new namespace.
-
#create_project_location_namespace_service(parent, service_object = nil, service_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ServicedirectoryV1beta1::Service
Creates a service, and returns the new service.
-
#create_project_location_namespace_service_endpoint(parent, endpoint_object = nil, endpoint_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ServicedirectoryV1beta1::Endpoint
Creates an endpoint, and returns the new endpoint.
-
#delete_project_location_namespace(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ServicedirectoryV1beta1::Empty
Deletes a namespace.
-
#delete_project_location_namespace_service(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ServicedirectoryV1beta1::Empty
Deletes a service.
-
#delete_project_location_namespace_service_endpoint(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ServicedirectoryV1beta1::Empty
Deletes an endpoint.
-
#get_namespace_iam_policy(resource, get_iam_policy_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ServicedirectoryV1beta1::Policy
Gets the IAM Policy for a resource.
-
#get_project_location(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ServicedirectoryV1beta1::Location
Gets information about a location.
-
#get_project_location_namespace(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ServicedirectoryV1beta1::Namespace
Gets a namespace.
-
#get_project_location_namespace_service(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ServicedirectoryV1beta1::Service
Gets a service.
-
#get_project_location_namespace_service_endpoint(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ServicedirectoryV1beta1::Endpoint
Gets an endpoint.
-
#get_service_iam_policy(resource, get_iam_policy_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ServicedirectoryV1beta1::Policy
Gets the IAM Policy for a resource.
-
#get_workload_iam_policy(resource, get_iam_policy_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ServicedirectoryV1beta1::Policy
Gets the IAM Policy for a resource.
-
#initialize ⇒ ServiceDirectoryService
constructor
A new instance of ServiceDirectoryService.
-
#list_project_location_namespace_service_endpoints(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ServicedirectoryV1beta1::ListEndpointsResponse
Lists all endpoints.
-
#list_project_location_namespace_services(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ServicedirectoryV1beta1::ListServicesResponse
Lists all services belonging to a namespace.
-
#list_project_location_namespaces(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ServicedirectoryV1beta1::ListNamespacesResponse
Lists all namespaces.
-
#list_project_locations(name, extra_location_types: nil, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ServicedirectoryV1beta1::ListLocationsResponse
Lists information about the supported locations for this service.
-
#patch_project_location_namespace(name, namespace_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ServicedirectoryV1beta1::Namespace
Updates a namespace.
-
#patch_project_location_namespace_service(name, service_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ServicedirectoryV1beta1::Service
Updates a service.
-
#patch_project_location_namespace_service_endpoint(name, endpoint_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ServicedirectoryV1beta1::Endpoint
Updates an endpoint.
-
#resolve_service(name, resolve_service_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ServicedirectoryV1beta1::ResolveServiceResponse
Returns a service and its associated endpoints.
-
#set_namespace_iam_policy(resource, set_iam_policy_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ServicedirectoryV1beta1::Policy
Sets the IAM Policy for a resource.
-
#set_service_iam_policy(resource, set_iam_policy_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ServicedirectoryV1beta1::Policy
Sets the IAM Policy for a resource.
-
#set_workload_iam_policy(resource, set_iam_policy_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ServicedirectoryV1beta1::Policy
Sets the IAM Policy for a resource.
-
#test_namespace_iam_permissions(resource, test_iam_permissions_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ServicedirectoryV1beta1::TestIamPermissionsResponse
Tests IAM permissions for a resource (namespace, service or service workload only).
-
#test_service_iam_permissions(resource, test_iam_permissions_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ServicedirectoryV1beta1::TestIamPermissionsResponse
Tests IAM permissions for a resource (namespace, service or service workload only).
-
#test_workload_iam_permissions(resource, test_iam_permissions_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ServicedirectoryV1beta1::TestIamPermissionsResponse
Tests IAM permissions for a resource (namespace, service or service workload only).
Constructor Details
#initialize ⇒ ServiceDirectoryService
Returns a new instance of ServiceDirectoryService.
48 49 50 51 52 53 |
# File 'lib/google/apis/servicedirectory_v1beta1/service.rb', line 48 def initialize super(DEFAULT_ENDPOINT_TEMPLATE, '', client_name: 'google-apis-servicedirectory_v1beta1', client_version: Google::Apis::ServicedirectoryV1beta1::GEM_VERSION) @batch_path = 'batch' end |
Instance Attribute Details
#key ⇒ String
Returns API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.
41 42 43 |
# File 'lib/google/apis/servicedirectory_v1beta1/service.rb', line 41 def key @key end |
#quota_user ⇒ String
Returns Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.
46 47 48 |
# File 'lib/google/apis/servicedirectory_v1beta1/service.rb', line 46 def quota_user @quota_user end |
Instance Method Details
#create_project_location_namespace(parent, namespace_object = nil, namespace_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ServicedirectoryV1beta1::Namespace
Creates a namespace, and returns the new namespace.
170 171 172 173 174 175 176 177 178 179 180 181 |
# File 'lib/google/apis/servicedirectory_v1beta1/service.rb', line 170 def create_project_location_namespace(parent, namespace_object = nil, namespace_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1beta1/{+parent}/namespaces', ) command.request_representation = Google::Apis::ServicedirectoryV1beta1::Namespace::Representation command.request_object = namespace_object command.response_representation = Google::Apis::ServicedirectoryV1beta1::Namespace::Representation command.response_class = Google::Apis::ServicedirectoryV1beta1::Namespace command.params['parent'] = parent unless parent.nil? command.query['namespaceId'] = namespace_id unless namespace_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#create_project_location_namespace_service(parent, service_object = nil, service_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ServicedirectoryV1beta1::Service
Creates a service, and returns the new service.
478 479 480 481 482 483 484 485 486 487 488 489 |
# File 'lib/google/apis/servicedirectory_v1beta1/service.rb', line 478 def create_project_location_namespace_service(parent, service_object = nil, service_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1beta1/{+parent}/services', ) command.request_representation = Google::Apis::ServicedirectoryV1beta1::Service::Representation command.request_object = service_object command.response_representation = Google::Apis::ServicedirectoryV1beta1::Service::Representation command.response_class = Google::Apis::ServicedirectoryV1beta1::Service command.params['parent'] = parent unless parent.nil? command.query['serviceId'] = service_id unless service_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#create_project_location_namespace_service_endpoint(parent, endpoint_object = nil, endpoint_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ServicedirectoryV1beta1::Endpoint
Creates an endpoint, and returns the new endpoint.
818 819 820 821 822 823 824 825 826 827 828 829 |
# File 'lib/google/apis/servicedirectory_v1beta1/service.rb', line 818 def create_project_location_namespace_service_endpoint(parent, endpoint_object = nil, endpoint_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1beta1/{+parent}/endpoints', ) command.request_representation = Google::Apis::ServicedirectoryV1beta1::Endpoint::Representation command.request_object = endpoint_object command.response_representation = Google::Apis::ServicedirectoryV1beta1::Endpoint::Representation command.response_class = Google::Apis::ServicedirectoryV1beta1::Endpoint command.params['parent'] = parent unless parent.nil? command.query['endpointId'] = endpoint_id unless endpoint_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_project_location_namespace(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ServicedirectoryV1beta1::Empty
Deletes a namespace. This also deletes all services and endpoints in the namespace.
204 205 206 207 208 209 210 211 212 |
# File 'lib/google/apis/servicedirectory_v1beta1/service.rb', line 204 def delete_project_location_namespace(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v1beta1/{+name}', ) command.response_representation = Google::Apis::ServicedirectoryV1beta1::Empty::Representation command.response_class = Google::Apis::ServicedirectoryV1beta1::Empty command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_project_location_namespace_service(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ServicedirectoryV1beta1::Empty
Deletes a service. This also deletes all endpoints associated with the service.
511 512 513 514 515 516 517 518 519 |
# File 'lib/google/apis/servicedirectory_v1beta1/service.rb', line 511 def delete_project_location_namespace_service(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v1beta1/{+name}', ) command.response_representation = Google::Apis::ServicedirectoryV1beta1::Empty::Representation command.response_class = Google::Apis::ServicedirectoryV1beta1::Empty command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_project_location_namespace_service_endpoint(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ServicedirectoryV1beta1::Empty
Deletes an endpoint.
851 852 853 854 855 856 857 858 859 |
# File 'lib/google/apis/servicedirectory_v1beta1/service.rb', line 851 def delete_project_location_namespace_service_endpoint(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v1beta1/{+name}', ) command.response_representation = Google::Apis::ServicedirectoryV1beta1::Empty::Representation command.response_class = Google::Apis::ServicedirectoryV1beta1::Empty command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_namespace_iam_policy(resource, get_iam_policy_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ServicedirectoryV1beta1::Policy
Gets the IAM Policy for a resource
267 268 269 270 271 272 273 274 275 276 277 |
# File 'lib/google/apis/servicedirectory_v1beta1/service.rb', line 267 def get_namespace_iam_policy(resource, get_iam_policy_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1beta1/{+resource}:getIamPolicy', ) command.request_representation = Google::Apis::ServicedirectoryV1beta1::GetIamPolicyRequest::Representation command.request_object = get_iam_policy_request_object command.response_representation = Google::Apis::ServicedirectoryV1beta1::Policy::Representation command.response_class = Google::Apis::ServicedirectoryV1beta1::Policy command.params['resource'] = resource unless resource.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ServicedirectoryV1beta1::Location
Gets information about a location.
75 76 77 78 79 80 81 82 83 |
# File 'lib/google/apis/servicedirectory_v1beta1/service.rb', line 75 def get_project_location(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta1/{+name}', ) command.response_representation = Google::Apis::ServicedirectoryV1beta1::Location::Representation command.response_class = Google::Apis::ServicedirectoryV1beta1::Location command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_namespace(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ServicedirectoryV1beta1::Namespace
Gets a namespace.
234 235 236 237 238 239 240 241 242 |
# File 'lib/google/apis/servicedirectory_v1beta1/service.rb', line 234 def get_project_location_namespace(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta1/{+name}', ) command.response_representation = Google::Apis::ServicedirectoryV1beta1::Namespace::Representation command.response_class = Google::Apis::ServicedirectoryV1beta1::Namespace command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_namespace_service(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ServicedirectoryV1beta1::Service
Gets a service.
541 542 543 544 545 546 547 548 549 |
# File 'lib/google/apis/servicedirectory_v1beta1/service.rb', line 541 def get_project_location_namespace_service(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta1/{+name}', ) command.response_representation = Google::Apis::ServicedirectoryV1beta1::Service::Representation command.response_class = Google::Apis::ServicedirectoryV1beta1::Service command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_namespace_service_endpoint(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ServicedirectoryV1beta1::Endpoint
Gets an endpoint.
881 882 883 884 885 886 887 888 889 |
# File 'lib/google/apis/servicedirectory_v1beta1/service.rb', line 881 def get_project_location_namespace_service_endpoint(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta1/{+name}', ) command.response_representation = Google::Apis::ServicedirectoryV1beta1::Endpoint::Representation command.response_class = Google::Apis::ServicedirectoryV1beta1::Endpoint command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_service_iam_policy(resource, get_iam_policy_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ServicedirectoryV1beta1::Policy
Gets the IAM Policy for a resource
574 575 576 577 578 579 580 581 582 583 584 |
# File 'lib/google/apis/servicedirectory_v1beta1/service.rb', line 574 def get_service_iam_policy(resource, get_iam_policy_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1beta1/{+resource}:getIamPolicy', ) command.request_representation = Google::Apis::ServicedirectoryV1beta1::GetIamPolicyRequest::Representation command.request_object = get_iam_policy_request_object command.response_representation = Google::Apis::ServicedirectoryV1beta1::Policy::Representation command.response_class = Google::Apis::ServicedirectoryV1beta1::Policy command.params['resource'] = resource unless resource.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_workload_iam_policy(resource, get_iam_policy_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ServicedirectoryV1beta1::Policy
Gets the IAM Policy for a resource
1018 1019 1020 1021 1022 1023 1024 1025 1026 1027 1028 |
# File 'lib/google/apis/servicedirectory_v1beta1/service.rb', line 1018 def get_workload_iam_policy(resource, get_iam_policy_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1beta1/{+resource}:getIamPolicy', ) command.request_representation = Google::Apis::ServicedirectoryV1beta1::GetIamPolicyRequest::Representation command.request_object = get_iam_policy_request_object command.response_representation = Google::Apis::ServicedirectoryV1beta1::Policy::Representation command.response_class = Google::Apis::ServicedirectoryV1beta1::Policy command.params['resource'] = resource unless resource.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_namespace_service_endpoints(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ServicedirectoryV1beta1::ListEndpointsResponse
Lists all endpoints.
944 945 946 947 948 949 950 951 952 953 954 955 956 |
# File 'lib/google/apis/servicedirectory_v1beta1/service.rb', line 944 def list_project_location_namespace_service_endpoints(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta1/{+parent}/endpoints', ) command.response_representation = Google::Apis::ServicedirectoryV1beta1::ListEndpointsResponse::Representation command.response_class = Google::Apis::ServicedirectoryV1beta1::ListEndpointsResponse command.params['parent'] = parent unless parent.nil? command.query['filter'] = filter unless filter.nil? command.query['orderBy'] = order_by unless order_by.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_namespace_services(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ServicedirectoryV1beta1::ListServicesResponse
Lists all services belonging to a namespace.
634 635 636 637 638 639 640 641 642 643 644 645 646 |
# File 'lib/google/apis/servicedirectory_v1beta1/service.rb', line 634 def list_project_location_namespace_services(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta1/{+parent}/services', ) command.response_representation = Google::Apis::ServicedirectoryV1beta1::ListServicesResponse::Representation command.response_class = Google::Apis::ServicedirectoryV1beta1::ListServicesResponse command.params['parent'] = parent unless parent.nil? command.query['filter'] = filter unless filter.nil? command.query['orderBy'] = order_by unless order_by.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_namespaces(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ServicedirectoryV1beta1::ListNamespacesResponse
Lists all namespaces.
328 329 330 331 332 333 334 335 336 337 338 339 340 |
# File 'lib/google/apis/servicedirectory_v1beta1/service.rb', line 328 def list_project_location_namespaces(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta1/{+parent}/namespaces', ) command.response_representation = Google::Apis::ServicedirectoryV1beta1::ListNamespacesResponse::Representation command.response_class = Google::Apis::ServicedirectoryV1beta1::ListNamespacesResponse command.params['parent'] = parent unless parent.nil? command.query['filter'] = filter unless filter.nil? command.query['orderBy'] = order_by unless order_by.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_locations(name, extra_location_types: nil, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ServicedirectoryV1beta1::ListLocationsResponse
Lists information about the supported locations for this service. This method
lists locations based on the resource scope provided in the [
ListLocationsRequest.name] field: * Global locations: If name is empty,
the method lists the public locations available to all projects. * Project-
specific locations: If name follows the format projects/project`, the
method lists locations visible to that specific project. This includes public,
private, or other project-specific locations enabled for the project. For gRPC
and client library implementations, the resource name is passed as thename`
field. For direct service calls, the resource name is incorporated into the
request path based on the specific service implementation and version.
127 128 129 130 131 132 133 134 135 136 137 138 139 |
# File 'lib/google/apis/servicedirectory_v1beta1/service.rb', line 127 def list_project_locations(name, extra_location_types: nil, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta1/{+name}/locations', ) command.response_representation = Google::Apis::ServicedirectoryV1beta1::ListLocationsResponse::Representation command.response_class = Google::Apis::ServicedirectoryV1beta1::ListLocationsResponse command.params['name'] = name unless name.nil? command.query['extraLocationTypes'] = extra_location_types unless extra_location_types.nil? command.query['filter'] = filter unless filter.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#patch_project_location_namespace(name, namespace_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ServicedirectoryV1beta1::Namespace
Updates a namespace.
366 367 368 369 370 371 372 373 374 375 376 377 |
# File 'lib/google/apis/servicedirectory_v1beta1/service.rb', line 366 def patch_project_location_namespace(name, namespace_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:patch, 'v1beta1/{+name}', ) command.request_representation = Google::Apis::ServicedirectoryV1beta1::Namespace::Representation command.request_object = namespace_object command.response_representation = Google::Apis::ServicedirectoryV1beta1::Namespace::Representation command.response_class = Google::Apis::ServicedirectoryV1beta1::Namespace command.params['name'] = name unless name.nil? command.query['updateMask'] = update_mask unless update_mask.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#patch_project_location_namespace_service(name, service_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ServicedirectoryV1beta1::Service
Updates a service.
672 673 674 675 676 677 678 679 680 681 682 683 |
# File 'lib/google/apis/servicedirectory_v1beta1/service.rb', line 672 def patch_project_location_namespace_service(name, service_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:patch, 'v1beta1/{+name}', ) command.request_representation = Google::Apis::ServicedirectoryV1beta1::Service::Representation command.request_object = service_object command.response_representation = Google::Apis::ServicedirectoryV1beta1::Service::Representation command.response_class = Google::Apis::ServicedirectoryV1beta1::Service command.params['name'] = name unless name.nil? command.query['updateMask'] = update_mask unless update_mask.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#patch_project_location_namespace_service_endpoint(name, endpoint_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ServicedirectoryV1beta1::Endpoint
Updates an endpoint.
982 983 984 985 986 987 988 989 990 991 992 993 |
# File 'lib/google/apis/servicedirectory_v1beta1/service.rb', line 982 def patch_project_location_namespace_service_endpoint(name, endpoint_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:patch, 'v1beta1/{+name}', ) command.request_representation = Google::Apis::ServicedirectoryV1beta1::Endpoint::Representation command.request_object = endpoint_object command.response_representation = Google::Apis::ServicedirectoryV1beta1::Endpoint::Representation command.response_class = Google::Apis::ServicedirectoryV1beta1::Endpoint command.params['name'] = name unless name.nil? command.query['updateMask'] = update_mask unless update_mask.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#resolve_service(name, resolve_service_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ServicedirectoryV1beta1::ResolveServiceResponse
Returns a service and its associated endpoints. Resolving a service is not considered an active developer method.
707 708 709 710 711 712 713 714 715 716 717 |
# File 'lib/google/apis/servicedirectory_v1beta1/service.rb', line 707 def resolve_service(name, resolve_service_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1beta1/{+name}:resolve', ) command.request_representation = Google::Apis::ServicedirectoryV1beta1::ResolveServiceRequest::Representation command.request_object = resolve_service_request_object command.response_representation = Google::Apis::ServicedirectoryV1beta1::ResolveServiceResponse::Representation command.response_class = Google::Apis::ServicedirectoryV1beta1::ResolveServiceResponse command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#set_namespace_iam_policy(resource, set_iam_policy_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ServicedirectoryV1beta1::Policy
Sets the IAM Policy for a resource
402 403 404 405 406 407 408 409 410 411 412 |
# File 'lib/google/apis/servicedirectory_v1beta1/service.rb', line 402 def set_namespace_iam_policy(resource, set_iam_policy_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1beta1/{+resource}:setIamPolicy', ) command.request_representation = Google::Apis::ServicedirectoryV1beta1::SetIamPolicyRequest::Representation command.request_object = set_iam_policy_request_object command.response_representation = Google::Apis::ServicedirectoryV1beta1::Policy::Representation command.response_class = Google::Apis::ServicedirectoryV1beta1::Policy command.params['resource'] = resource unless resource.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#set_service_iam_policy(resource, set_iam_policy_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ServicedirectoryV1beta1::Policy
Sets the IAM Policy for a resource
742 743 744 745 746 747 748 749 750 751 752 |
# File 'lib/google/apis/servicedirectory_v1beta1/service.rb', line 742 def set_service_iam_policy(resource, set_iam_policy_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1beta1/{+resource}:setIamPolicy', ) command.request_representation = Google::Apis::ServicedirectoryV1beta1::SetIamPolicyRequest::Representation command.request_object = set_iam_policy_request_object command.response_representation = Google::Apis::ServicedirectoryV1beta1::Policy::Representation command.response_class = Google::Apis::ServicedirectoryV1beta1::Policy command.params['resource'] = resource unless resource.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#set_workload_iam_policy(resource, set_iam_policy_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ServicedirectoryV1beta1::Policy
Sets the IAM Policy for a resource
1053 1054 1055 1056 1057 1058 1059 1060 1061 1062 1063 |
# File 'lib/google/apis/servicedirectory_v1beta1/service.rb', line 1053 def set_workload_iam_policy(resource, set_iam_policy_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1beta1/{+resource}:setIamPolicy', ) command.request_representation = Google::Apis::ServicedirectoryV1beta1::SetIamPolicyRequest::Representation command.request_object = set_iam_policy_request_object command.response_representation = Google::Apis::ServicedirectoryV1beta1::Policy::Representation command.response_class = Google::Apis::ServicedirectoryV1beta1::Policy command.params['resource'] = resource unless resource.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#test_namespace_iam_permissions(resource, test_iam_permissions_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ServicedirectoryV1beta1::TestIamPermissionsResponse
Tests IAM permissions for a resource (namespace, service or service workload only).
438 439 440 441 442 443 444 445 446 447 448 |
# File 'lib/google/apis/servicedirectory_v1beta1/service.rb', line 438 def (resource, = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1beta1/{+resource}:testIamPermissions', ) command.request_representation = Google::Apis::ServicedirectoryV1beta1::TestIamPermissionsRequest::Representation command.request_object = command.response_representation = Google::Apis::ServicedirectoryV1beta1::TestIamPermissionsResponse::Representation command.response_class = Google::Apis::ServicedirectoryV1beta1::TestIamPermissionsResponse command.params['resource'] = resource unless resource.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#test_service_iam_permissions(resource, test_iam_permissions_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ServicedirectoryV1beta1::TestIamPermissionsResponse
Tests IAM permissions for a resource (namespace, service or service workload only).
778 779 780 781 782 783 784 785 786 787 788 |
# File 'lib/google/apis/servicedirectory_v1beta1/service.rb', line 778 def (resource, = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1beta1/{+resource}:testIamPermissions', ) command.request_representation = Google::Apis::ServicedirectoryV1beta1::TestIamPermissionsRequest::Representation command.request_object = command.response_representation = Google::Apis::ServicedirectoryV1beta1::TestIamPermissionsResponse::Representation command.response_class = Google::Apis::ServicedirectoryV1beta1::TestIamPermissionsResponse command.params['resource'] = resource unless resource.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#test_workload_iam_permissions(resource, test_iam_permissions_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ServicedirectoryV1beta1::TestIamPermissionsResponse
Tests IAM permissions for a resource (namespace, service or service workload only).
1089 1090 1091 1092 1093 1094 1095 1096 1097 1098 1099 |
# File 'lib/google/apis/servicedirectory_v1beta1/service.rb', line 1089 def (resource, = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1beta1/{+resource}:testIamPermissions', ) command.request_representation = Google::Apis::ServicedirectoryV1beta1::TestIamPermissionsRequest::Representation command.request_object = command.response_representation = Google::Apis::ServicedirectoryV1beta1::TestIamPermissionsResponse::Representation command.response_class = Google::Apis::ServicedirectoryV1beta1::TestIamPermissionsResponse command.params['resource'] = resource unless resource.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |