Class: Google::Apis::ServicedirectoryV1beta1::ServiceDirectoryService
- Inherits:
-
Core::BaseService
- Object
- Core::BaseService
- Google::Apis::ServicedirectoryV1beta1::ServiceDirectoryService
- Defined in:
- lib/google/apis/servicedirectory_v1beta1/service.rb
Overview
Service Directory API
Service Directory is a platform for discovering, publishing, and connecting services.
Constant Summary collapse
- DEFAULT_ENDPOINT_TEMPLATE =
"https://servicedirectory.$UNIVERSE_DOMAIN$/"
Instance Attribute Summary collapse
-
#key ⇒ String
API key.
-
#quota_user ⇒ String
Available to use for quota purposes for server-side applications.
Instance Method Summary collapse
-
#create_project_location_namespace(parent, namespace_object = nil, namespace_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ServicedirectoryV1beta1::Namespace
Creates a namespace, and returns the new namespace.
-
#create_project_location_namespace_service(parent, service_object = nil, service_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ServicedirectoryV1beta1::Service
Creates a service, and returns the new service.
-
#create_project_location_namespace_service_endpoint(parent, endpoint_object = nil, endpoint_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ServicedirectoryV1beta1::Endpoint
Creates an endpoint, and returns the new endpoint.
-
#delete_project_location_namespace(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ServicedirectoryV1beta1::Empty
Deletes a namespace.
-
#delete_project_location_namespace_service(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ServicedirectoryV1beta1::Empty
Deletes a service.
-
#delete_project_location_namespace_service_endpoint(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ServicedirectoryV1beta1::Empty
Deletes an endpoint.
-
#get_namespace_iam_policy(resource, get_iam_policy_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ServicedirectoryV1beta1::Policy
Gets the IAM Policy for a resource.
-
#get_project_location(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ServicedirectoryV1beta1::Location
Gets information about a location.
-
#get_project_location_namespace(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ServicedirectoryV1beta1::Namespace
Gets a namespace.
-
#get_project_location_namespace_service(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ServicedirectoryV1beta1::Service
Gets a service.
-
#get_project_location_namespace_service_endpoint(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ServicedirectoryV1beta1::Endpoint
Gets an endpoint.
-
#get_service_iam_policy(resource, get_iam_policy_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ServicedirectoryV1beta1::Policy
Gets the IAM Policy for a resource.
-
#get_workload_iam_policy(resource, get_iam_policy_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ServicedirectoryV1beta1::Policy
Gets the IAM Policy for a resource.
-
#initialize ⇒ ServiceDirectoryService
constructor
A new instance of ServiceDirectoryService.
-
#list_project_location_namespace_service_endpoints(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ServicedirectoryV1beta1::ListEndpointsResponse
Lists all endpoints.
-
#list_project_location_namespace_services(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ServicedirectoryV1beta1::ListServicesResponse
Lists all services belonging to a namespace.
-
#list_project_location_namespaces(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ServicedirectoryV1beta1::ListNamespacesResponse
Lists all namespaces.
-
#list_project_locations(name, extra_location_types: nil, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ServicedirectoryV1beta1::ListLocationsResponse
Lists information about the supported locations for this service.
-
#patch_project_location_namespace(name, namespace_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ServicedirectoryV1beta1::Namespace
Updates a namespace.
-
#patch_project_location_namespace_service(name, service_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ServicedirectoryV1beta1::Service
Updates a service.
-
#patch_project_location_namespace_service_endpoint(name, endpoint_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ServicedirectoryV1beta1::Endpoint
Updates an endpoint.
-
#resolve_service(name, resolve_service_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ServicedirectoryV1beta1::ResolveServiceResponse
Returns a service and its associated endpoints.
-
#set_namespace_iam_policy(resource, set_iam_policy_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ServicedirectoryV1beta1::Policy
Sets the IAM Policy for a resource.
-
#set_service_iam_policy(resource, set_iam_policy_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ServicedirectoryV1beta1::Policy
Sets the IAM Policy for a resource.
-
#set_workload_iam_policy(resource, set_iam_policy_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ServicedirectoryV1beta1::Policy
Sets the IAM Policy for a resource.
-
#test_namespace_iam_permissions(resource, test_iam_permissions_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ServicedirectoryV1beta1::TestIamPermissionsResponse
Tests IAM permissions for a resource (namespace, service or service workload only).
-
#test_service_iam_permissions(resource, test_iam_permissions_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ServicedirectoryV1beta1::TestIamPermissionsResponse
Tests IAM permissions for a resource (namespace, service or service workload only).
-
#test_workload_iam_permissions(resource, test_iam_permissions_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ServicedirectoryV1beta1::TestIamPermissionsResponse
Tests IAM permissions for a resource (namespace, service or service workload only).
Constructor Details
#initialize ⇒ ServiceDirectoryService
Returns a new instance of ServiceDirectoryService.
48 49 50 51 52 53 |
# File 'lib/google/apis/servicedirectory_v1beta1/service.rb', line 48 def initialize super(DEFAULT_ENDPOINT_TEMPLATE, '', client_name: 'google-apis-servicedirectory_v1beta1', client_version: Google::Apis::ServicedirectoryV1beta1::GEM_VERSION) @batch_path = 'batch' end |
Instance Attribute Details
#key ⇒ String
Returns API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.
41 42 43 |
# File 'lib/google/apis/servicedirectory_v1beta1/service.rb', line 41 def key @key end |
#quota_user ⇒ String
Returns Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.
46 47 48 |
# File 'lib/google/apis/servicedirectory_v1beta1/service.rb', line 46 def quota_user @quota_user end |
Instance Method Details
#create_project_location_namespace(parent, namespace_object = nil, namespace_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ServicedirectoryV1beta1::Namespace
Creates a namespace, and returns the new namespace.
165 166 167 168 169 170 171 172 173 174 175 176 |
# File 'lib/google/apis/servicedirectory_v1beta1/service.rb', line 165 def create_project_location_namespace(parent, namespace_object = nil, namespace_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1beta1/{+parent}/namespaces', ) command.request_representation = Google::Apis::ServicedirectoryV1beta1::Namespace::Representation command.request_object = namespace_object command.response_representation = Google::Apis::ServicedirectoryV1beta1::Namespace::Representation command.response_class = Google::Apis::ServicedirectoryV1beta1::Namespace command.params['parent'] = parent unless parent.nil? command.query['namespaceId'] = namespace_id unless namespace_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#create_project_location_namespace_service(parent, service_object = nil, service_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ServicedirectoryV1beta1::Service
Creates a service, and returns the new service.
473 474 475 476 477 478 479 480 481 482 483 484 |
# File 'lib/google/apis/servicedirectory_v1beta1/service.rb', line 473 def create_project_location_namespace_service(parent, service_object = nil, service_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1beta1/{+parent}/services', ) command.request_representation = Google::Apis::ServicedirectoryV1beta1::Service::Representation command.request_object = service_object command.response_representation = Google::Apis::ServicedirectoryV1beta1::Service::Representation command.response_class = Google::Apis::ServicedirectoryV1beta1::Service command.params['parent'] = parent unless parent.nil? command.query['serviceId'] = service_id unless service_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#create_project_location_namespace_service_endpoint(parent, endpoint_object = nil, endpoint_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ServicedirectoryV1beta1::Endpoint
Creates an endpoint, and returns the new endpoint.
813 814 815 816 817 818 819 820 821 822 823 824 |
# File 'lib/google/apis/servicedirectory_v1beta1/service.rb', line 813 def create_project_location_namespace_service_endpoint(parent, endpoint_object = nil, endpoint_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1beta1/{+parent}/endpoints', ) command.request_representation = Google::Apis::ServicedirectoryV1beta1::Endpoint::Representation command.request_object = endpoint_object command.response_representation = Google::Apis::ServicedirectoryV1beta1::Endpoint::Representation command.response_class = Google::Apis::ServicedirectoryV1beta1::Endpoint command.params['parent'] = parent unless parent.nil? command.query['endpointId'] = endpoint_id unless endpoint_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_project_location_namespace(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ServicedirectoryV1beta1::Empty
Deletes a namespace. This also deletes all services and endpoints in the namespace.
199 200 201 202 203 204 205 206 207 |
# File 'lib/google/apis/servicedirectory_v1beta1/service.rb', line 199 def delete_project_location_namespace(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v1beta1/{+name}', ) command.response_representation = Google::Apis::ServicedirectoryV1beta1::Empty::Representation command.response_class = Google::Apis::ServicedirectoryV1beta1::Empty command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_project_location_namespace_service(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ServicedirectoryV1beta1::Empty
Deletes a service. This also deletes all endpoints associated with the service.
506 507 508 509 510 511 512 513 514 |
# File 'lib/google/apis/servicedirectory_v1beta1/service.rb', line 506 def delete_project_location_namespace_service(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v1beta1/{+name}', ) command.response_representation = Google::Apis::ServicedirectoryV1beta1::Empty::Representation command.response_class = Google::Apis::ServicedirectoryV1beta1::Empty command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_project_location_namespace_service_endpoint(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ServicedirectoryV1beta1::Empty
Deletes an endpoint.
846 847 848 849 850 851 852 853 854 |
# File 'lib/google/apis/servicedirectory_v1beta1/service.rb', line 846 def delete_project_location_namespace_service_endpoint(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v1beta1/{+name}', ) command.response_representation = Google::Apis::ServicedirectoryV1beta1::Empty::Representation command.response_class = Google::Apis::ServicedirectoryV1beta1::Empty command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_namespace_iam_policy(resource, get_iam_policy_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ServicedirectoryV1beta1::Policy
Gets the IAM Policy for a resource
262 263 264 265 266 267 268 269 270 271 272 |
# File 'lib/google/apis/servicedirectory_v1beta1/service.rb', line 262 def get_namespace_iam_policy(resource, get_iam_policy_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1beta1/{+resource}:getIamPolicy', ) command.request_representation = Google::Apis::ServicedirectoryV1beta1::GetIamPolicyRequest::Representation command.request_object = get_iam_policy_request_object command.response_representation = Google::Apis::ServicedirectoryV1beta1::Policy::Representation command.response_class = Google::Apis::ServicedirectoryV1beta1::Policy command.params['resource'] = resource unless resource.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ServicedirectoryV1beta1::Location
Gets information about a location.
75 76 77 78 79 80 81 82 83 |
# File 'lib/google/apis/servicedirectory_v1beta1/service.rb', line 75 def get_project_location(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta1/{+name}', ) command.response_representation = Google::Apis::ServicedirectoryV1beta1::Location::Representation command.response_class = Google::Apis::ServicedirectoryV1beta1::Location command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_namespace(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ServicedirectoryV1beta1::Namespace
Gets a namespace.
229 230 231 232 233 234 235 236 237 |
# File 'lib/google/apis/servicedirectory_v1beta1/service.rb', line 229 def get_project_location_namespace(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta1/{+name}', ) command.response_representation = Google::Apis::ServicedirectoryV1beta1::Namespace::Representation command.response_class = Google::Apis::ServicedirectoryV1beta1::Namespace command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_namespace_service(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ServicedirectoryV1beta1::Service
Gets a service.
536 537 538 539 540 541 542 543 544 |
# File 'lib/google/apis/servicedirectory_v1beta1/service.rb', line 536 def get_project_location_namespace_service(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta1/{+name}', ) command.response_representation = Google::Apis::ServicedirectoryV1beta1::Service::Representation command.response_class = Google::Apis::ServicedirectoryV1beta1::Service command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_namespace_service_endpoint(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ServicedirectoryV1beta1::Endpoint
Gets an endpoint.
876 877 878 879 880 881 882 883 884 |
# File 'lib/google/apis/servicedirectory_v1beta1/service.rb', line 876 def get_project_location_namespace_service_endpoint(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta1/{+name}', ) command.response_representation = Google::Apis::ServicedirectoryV1beta1::Endpoint::Representation command.response_class = Google::Apis::ServicedirectoryV1beta1::Endpoint command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_service_iam_policy(resource, get_iam_policy_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ServicedirectoryV1beta1::Policy
Gets the IAM Policy for a resource
569 570 571 572 573 574 575 576 577 578 579 |
# File 'lib/google/apis/servicedirectory_v1beta1/service.rb', line 569 def get_service_iam_policy(resource, get_iam_policy_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1beta1/{+resource}:getIamPolicy', ) command.request_representation = Google::Apis::ServicedirectoryV1beta1::GetIamPolicyRequest::Representation command.request_object = get_iam_policy_request_object command.response_representation = Google::Apis::ServicedirectoryV1beta1::Policy::Representation command.response_class = Google::Apis::ServicedirectoryV1beta1::Policy command.params['resource'] = resource unless resource.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_workload_iam_policy(resource, get_iam_policy_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ServicedirectoryV1beta1::Policy
Gets the IAM Policy for a resource
1013 1014 1015 1016 1017 1018 1019 1020 1021 1022 1023 |
# File 'lib/google/apis/servicedirectory_v1beta1/service.rb', line 1013 def get_workload_iam_policy(resource, get_iam_policy_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1beta1/{+resource}:getIamPolicy', ) command.request_representation = Google::Apis::ServicedirectoryV1beta1::GetIamPolicyRequest::Representation command.request_object = get_iam_policy_request_object command.response_representation = Google::Apis::ServicedirectoryV1beta1::Policy::Representation command.response_class = Google::Apis::ServicedirectoryV1beta1::Policy command.params['resource'] = resource unless resource.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_namespace_service_endpoints(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ServicedirectoryV1beta1::ListEndpointsResponse
Lists all endpoints.
939 940 941 942 943 944 945 946 947 948 949 950 951 |
# File 'lib/google/apis/servicedirectory_v1beta1/service.rb', line 939 def list_project_location_namespace_service_endpoints(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta1/{+parent}/endpoints', ) command.response_representation = Google::Apis::ServicedirectoryV1beta1::ListEndpointsResponse::Representation command.response_class = Google::Apis::ServicedirectoryV1beta1::ListEndpointsResponse command.params['parent'] = parent unless parent.nil? command.query['filter'] = filter unless filter.nil? command.query['orderBy'] = order_by unless order_by.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_namespace_services(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ServicedirectoryV1beta1::ListServicesResponse
Lists all services belonging to a namespace.
629 630 631 632 633 634 635 636 637 638 639 640 641 |
# File 'lib/google/apis/servicedirectory_v1beta1/service.rb', line 629 def list_project_location_namespace_services(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta1/{+parent}/services', ) command.response_representation = Google::Apis::ServicedirectoryV1beta1::ListServicesResponse::Representation command.response_class = Google::Apis::ServicedirectoryV1beta1::ListServicesResponse command.params['parent'] = parent unless parent.nil? command.query['filter'] = filter unless filter.nil? command.query['orderBy'] = order_by unless order_by.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_namespaces(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ServicedirectoryV1beta1::ListNamespacesResponse
Lists all namespaces.
323 324 325 326 327 328 329 330 331 332 333 334 335 |
# File 'lib/google/apis/servicedirectory_v1beta1/service.rb', line 323 def list_project_location_namespaces(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta1/{+parent}/namespaces', ) command.response_representation = Google::Apis::ServicedirectoryV1beta1::ListNamespacesResponse::Representation command.response_class = Google::Apis::ServicedirectoryV1beta1::ListNamespacesResponse command.params['parent'] = parent unless parent.nil? command.query['filter'] = filter unless filter.nil? command.query['orderBy'] = order_by unless order_by.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_locations(name, extra_location_types: nil, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ServicedirectoryV1beta1::ListLocationsResponse
Lists information about the supported locations for this service. This method
can be called in two ways: * List all public locations: Use the path GET /
v1/locations. * List project-visible locations: Use the path GET /v1/
projects/project_id/locations. This may include public locations as well as
private or other locations specifically visible to the project.
122 123 124 125 126 127 128 129 130 131 132 133 134 |
# File 'lib/google/apis/servicedirectory_v1beta1/service.rb', line 122 def list_project_locations(name, extra_location_types: nil, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta1/{+name}/locations', ) command.response_representation = Google::Apis::ServicedirectoryV1beta1::ListLocationsResponse::Representation command.response_class = Google::Apis::ServicedirectoryV1beta1::ListLocationsResponse command.params['name'] = name unless name.nil? command.query['extraLocationTypes'] = extra_location_types unless extra_location_types.nil? command.query['filter'] = filter unless filter.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#patch_project_location_namespace(name, namespace_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ServicedirectoryV1beta1::Namespace
Updates a namespace.
361 362 363 364 365 366 367 368 369 370 371 372 |
# File 'lib/google/apis/servicedirectory_v1beta1/service.rb', line 361 def patch_project_location_namespace(name, namespace_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:patch, 'v1beta1/{+name}', ) command.request_representation = Google::Apis::ServicedirectoryV1beta1::Namespace::Representation command.request_object = namespace_object command.response_representation = Google::Apis::ServicedirectoryV1beta1::Namespace::Representation command.response_class = Google::Apis::ServicedirectoryV1beta1::Namespace command.params['name'] = name unless name.nil? command.query['updateMask'] = update_mask unless update_mask.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#patch_project_location_namespace_service(name, service_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ServicedirectoryV1beta1::Service
Updates a service.
667 668 669 670 671 672 673 674 675 676 677 678 |
# File 'lib/google/apis/servicedirectory_v1beta1/service.rb', line 667 def patch_project_location_namespace_service(name, service_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:patch, 'v1beta1/{+name}', ) command.request_representation = Google::Apis::ServicedirectoryV1beta1::Service::Representation command.request_object = service_object command.response_representation = Google::Apis::ServicedirectoryV1beta1::Service::Representation command.response_class = Google::Apis::ServicedirectoryV1beta1::Service command.params['name'] = name unless name.nil? command.query['updateMask'] = update_mask unless update_mask.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#patch_project_location_namespace_service_endpoint(name, endpoint_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ServicedirectoryV1beta1::Endpoint
Updates an endpoint.
977 978 979 980 981 982 983 984 985 986 987 988 |
# File 'lib/google/apis/servicedirectory_v1beta1/service.rb', line 977 def patch_project_location_namespace_service_endpoint(name, endpoint_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:patch, 'v1beta1/{+name}', ) command.request_representation = Google::Apis::ServicedirectoryV1beta1::Endpoint::Representation command.request_object = endpoint_object command.response_representation = Google::Apis::ServicedirectoryV1beta1::Endpoint::Representation command.response_class = Google::Apis::ServicedirectoryV1beta1::Endpoint command.params['name'] = name unless name.nil? command.query['updateMask'] = update_mask unless update_mask.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#resolve_service(name, resolve_service_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ServicedirectoryV1beta1::ResolveServiceResponse
Returns a service and its associated endpoints. Resolving a service is not considered an active developer method.
702 703 704 705 706 707 708 709 710 711 712 |
# File 'lib/google/apis/servicedirectory_v1beta1/service.rb', line 702 def resolve_service(name, resolve_service_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1beta1/{+name}:resolve', ) command.request_representation = Google::Apis::ServicedirectoryV1beta1::ResolveServiceRequest::Representation command.request_object = resolve_service_request_object command.response_representation = Google::Apis::ServicedirectoryV1beta1::ResolveServiceResponse::Representation command.response_class = Google::Apis::ServicedirectoryV1beta1::ResolveServiceResponse command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#set_namespace_iam_policy(resource, set_iam_policy_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ServicedirectoryV1beta1::Policy
Sets the IAM Policy for a resource
397 398 399 400 401 402 403 404 405 406 407 |
# File 'lib/google/apis/servicedirectory_v1beta1/service.rb', line 397 def set_namespace_iam_policy(resource, set_iam_policy_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1beta1/{+resource}:setIamPolicy', ) command.request_representation = Google::Apis::ServicedirectoryV1beta1::SetIamPolicyRequest::Representation command.request_object = set_iam_policy_request_object command.response_representation = Google::Apis::ServicedirectoryV1beta1::Policy::Representation command.response_class = Google::Apis::ServicedirectoryV1beta1::Policy command.params['resource'] = resource unless resource.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#set_service_iam_policy(resource, set_iam_policy_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ServicedirectoryV1beta1::Policy
Sets the IAM Policy for a resource
737 738 739 740 741 742 743 744 745 746 747 |
# File 'lib/google/apis/servicedirectory_v1beta1/service.rb', line 737 def set_service_iam_policy(resource, set_iam_policy_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1beta1/{+resource}:setIamPolicy', ) command.request_representation = Google::Apis::ServicedirectoryV1beta1::SetIamPolicyRequest::Representation command.request_object = set_iam_policy_request_object command.response_representation = Google::Apis::ServicedirectoryV1beta1::Policy::Representation command.response_class = Google::Apis::ServicedirectoryV1beta1::Policy command.params['resource'] = resource unless resource.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#set_workload_iam_policy(resource, set_iam_policy_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ServicedirectoryV1beta1::Policy
Sets the IAM Policy for a resource
1048 1049 1050 1051 1052 1053 1054 1055 1056 1057 1058 |
# File 'lib/google/apis/servicedirectory_v1beta1/service.rb', line 1048 def set_workload_iam_policy(resource, set_iam_policy_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1beta1/{+resource}:setIamPolicy', ) command.request_representation = Google::Apis::ServicedirectoryV1beta1::SetIamPolicyRequest::Representation command.request_object = set_iam_policy_request_object command.response_representation = Google::Apis::ServicedirectoryV1beta1::Policy::Representation command.response_class = Google::Apis::ServicedirectoryV1beta1::Policy command.params['resource'] = resource unless resource.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#test_namespace_iam_permissions(resource, test_iam_permissions_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ServicedirectoryV1beta1::TestIamPermissionsResponse
Tests IAM permissions for a resource (namespace, service or service workload only).
433 434 435 436 437 438 439 440 441 442 443 |
# File 'lib/google/apis/servicedirectory_v1beta1/service.rb', line 433 def (resource, = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1beta1/{+resource}:testIamPermissions', ) command.request_representation = Google::Apis::ServicedirectoryV1beta1::TestIamPermissionsRequest::Representation command.request_object = command.response_representation = Google::Apis::ServicedirectoryV1beta1::TestIamPermissionsResponse::Representation command.response_class = Google::Apis::ServicedirectoryV1beta1::TestIamPermissionsResponse command.params['resource'] = resource unless resource.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#test_service_iam_permissions(resource, test_iam_permissions_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ServicedirectoryV1beta1::TestIamPermissionsResponse
Tests IAM permissions for a resource (namespace, service or service workload only).
773 774 775 776 777 778 779 780 781 782 783 |
# File 'lib/google/apis/servicedirectory_v1beta1/service.rb', line 773 def (resource, = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1beta1/{+resource}:testIamPermissions', ) command.request_representation = Google::Apis::ServicedirectoryV1beta1::TestIamPermissionsRequest::Representation command.request_object = command.response_representation = Google::Apis::ServicedirectoryV1beta1::TestIamPermissionsResponse::Representation command.response_class = Google::Apis::ServicedirectoryV1beta1::TestIamPermissionsResponse command.params['resource'] = resource unless resource.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#test_workload_iam_permissions(resource, test_iam_permissions_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ServicedirectoryV1beta1::TestIamPermissionsResponse
Tests IAM permissions for a resource (namespace, service or service workload only).
1084 1085 1086 1087 1088 1089 1090 1091 1092 1093 1094 |
# File 'lib/google/apis/servicedirectory_v1beta1/service.rb', line 1084 def (resource, = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1beta1/{+resource}:testIamPermissions', ) command.request_representation = Google::Apis::ServicedirectoryV1beta1::TestIamPermissionsRequest::Representation command.request_object = command.response_representation = Google::Apis::ServicedirectoryV1beta1::TestIamPermissionsResponse::Representation command.response_class = Google::Apis::ServicedirectoryV1beta1::TestIamPermissionsResponse command.params['resource'] = resource unless resource.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |